@@ -125,7 +125,7 @@ class ActivityManager(base.ActivityManagerBase):
                 skip=skip, query=query)
 
 
-class Aggregator(object):
+class Aggregator:
     """Creates a timeline for a given node in the network graph."""
 
     def __init__(self, activity_manager, node_manager):
@@ -139,8 +139,8 @@ class Aggregator(object):
         attrs = ('actor', 'obj', 'target')
         seen, unique = [], []
         for activity in activities:
-            d = dict((a, ActivityObject.to_dict(getattr(activity, a)))
-                    for a in attrs)
+            d = {a: ActivityObject.to_dict(getattr(activity, a))
+                    for a in attrs}
             d.update(verb=activity.verb)
             if d in seen:
                 continue
@@ -181,10 +181,10 @@ class Aggregator(object):
                 # add activities for this node
                 activities += self.activity_manager.get_activities([node],
                         since=last_timeline_aggregation)
-                # if we don't have any activities at this point, there's nothing from
+                # if we don't have any new activities at this point, there's nothing from
                 # which to generate a timeline
                 if not activities:
-                    return self.activity_manager.get_timeline(node_id)
+                    return
                 # remove duplicates
                 activities = self._unique_activities(activities)
                 # classify and score activities
@@ -231,7 +231,7 @@ class Aggregator(object):
                 node_id, sort=[('score', -1)], skip=page*limit, limit=limit,
                 query=query_filter)
         if filter_func:
-            timeline = filter(filter_func, timeline)
+            timeline = list(filter(filter_func, timeline))
         return timeline
 
     def filter_connections(self, nodes):
