@@ -28,13 +28,13 @@ class PymongoStorage(Storage):
         if conf['activitystream.master'].startswith('mim://'):
             try:
                 from ming import mim
-            except ImportError, e:
+            except ImportError as e:
                 raise ImportError(str(e) + '. To use mim:// you must have the '
                         'ming package installed.')
             else:
                 return mim.Connection()
         else:
-            return pymongo.Connection(conf['activitystream.master'])
+            return pymongo.MongoClient(conf['activitystream.master'])
 
     def create_edge(self, from_node, to_node):
         """Create a directed edge from :class:`Node` ``follower`` to
